<template>
  <div class="container-fluid py-5 mb-5">
    <!-- Title -->
    <div class="mb-4 border-bottom pb-3">
      <h4 class="fw-bold text-dark mb-3">{{ t('support_user_page.title') }}</h4>
      <p class="text-muted font-size-14 mt-2">{{ t('support_user_page.intro') }}</p>
    </div>

    <!-- Accordion Section -->
    <div class="accordion mb-5" id="supportAccordion">
      <!-- Accordion Group Template -->
      <div
        class="accordion-item mb-3 border rounded overflow-hidden shadow-sm"
        v-for="(section, index) in sections"
        :key="index"
      >
        <h2 class="accordion-header  d-flex align-items-center justify-contant-between" :id="`heading-${index}`">
          <button
            class="accordion-button collapsed bg-white fw-semibold text-dark font-size-14"
            type="button"
            data-bs-toggle="collapse"
            :data-bs-target="`#collapse-${index}`"
          >
            {{ t(section.title) }}
          </button>
        </h2>
        <div
          :id="`collapse-${index}`"
          class="accordion-collapse collapse"
          :aria-labelledby="`heading-${index}`"
          data-bs-parent="#supportAccordion"
        >
          <div class="accordion-body">
            <ul class="ps-3">
              <li
                v-for="(item, i) in section.items"
                :key="i"
                class="mb-2 text-secondary"
              >
                {{ t(item) }}
              </li>
            </ul>
          </div>
        </div>
      </div>
    </div>

    <!-- Useful Links -->
    <div>
      <h6 class="fw-bold text-dark mb-3">{{ t('support_user_page.useful_links.title') }}</h6>
      <p class="text-muted mb-4 font-size-14">{{ t('support_user_page.useful_links.report_text') }}</p>
      <h6 class="fw-semibold mb-3 text-dark">{{ t('support_user_page.useful_links.resources_title') }}</h6>
      <div class="list-group">
        <a
          v-for="(link, index) in usefulLinks"
          :key="index"
          :href="link.href"
          target="_blank"
          class="list-group-item list-group-item-action d-flex justify-content-between align-items-center text-decoration-underline text-default border rounded shadow-sm my-2"
        >
          {{ t(link.label) }}
          <i class="bi bi-box-arrow-up-right text-primary"></i>
        </a>
      </div>
    </div>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n';
const { t } = useI18n();

const sections = [
  {
    title: 'support_user_page.warning_signs.title',
    items: Array.from({ length: 8 }, (_, i) => `support_user_page.warning_signs.items[${i}]`),
  },
  {
    title: 'support_user_page.in_person.title',
    items: Array.from({ length: 3 }, (_, i) => `support_user_page.in_person.items[${i}]`),
  },
  {
    title: 'support_user_page.payment_tips.title',
    items: Array.from({ length: 3 }, (_, i) => `support_user_page.payment_tips.items[${i}]`),
  },
  {
    title: 'support_user_page.pre_transaction.title',
    items: Array.from({ length: 6 }, (_, i) => `support_user_page.pre_transaction.items[${i}]`),
  },
  {
    title: 'support_user_page.remote_transactions.title',
    items: Array.from({ length: 6 }, (_, i) => `support_user_page.remote_transactions.items[${i}]`),
  },
  {
    title: 'support_user_page.car_leasing.title',
    items: Array.from({ length: 5 }, (_, i) => `support_user_page.car_leasing.items[${i}]`),
  },
  {
    title: 'support_user_page.artju_role.title',
    items: Array.from({ length: 5 }, (_, i) => `support_user_page.artju_role.items[${i}]`),
  },
];

const usefulLinks = [
  { href: 'https://sana.adliran.ir/', label: 'support_user_page.useful_links.links[0]' },
  { href: 'http://www.cyberpolice.ir/', label: 'support_user_page.useful_links.links[1]' },
  { href: 'http://service.rahvar120.ir/page/infractions', label: 'support_user_page.useful_links.links[2]' },
  { href: 'https://hamyab24.ir/', label: 'support_user_page.useful_links.links[3]' },
  { href: 'http://confirm.ssaa.ir/', label: 'support_user_page.useful_links.links[4]' },
  { href: 'http://inquirystatus.ssaa.ir/', label: 'support_user_page.useful_links.links[5]' },
  { href: 'http://irsherkat.ssaa.ir/Design/SearchCompanyPublicInfo.aspx', label: 'support_user_page.useful_links.links[6]' },
];
</script>

<style scoped>
.accordion-button {
  transition: all 0.3s ease;
  font-size: 1.1rem;
}
.accordion-button:focus {
  box-shadow: 0 0 0 0.2rem #ff9800;
  border-color: #ff9800;
}
.accordion-button:not(.collapsed) {
  background-color: #fff4e6;
  color: #ff9800;
}
.accordion-button::after {
  margin-right: auto !important;
  margin-left: 0 !important;
}
.accordion-item {
  border: 1px solid #ffc10720;
}
ul li {
  line-height: 1.8;
  font-size: 0.95rem;
}
.list-group-item {
  background-color: #f9f9f9;
  transition: all 0.2s ease-in-out;
}
.list-group-item:hover {
  background-color: #fff3e0;
  color: #ff9800;
}
</style>